pub struct VelocityLimit { /* private fields */ }Trait Implementations
Sourceimpl Clone for VelocityLimit
impl Clone for VelocityLimit
Sourcefn clone(&self) -> VelocityLimit
fn clone(&self) -> VelocityLimit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ContainerType for VelocityLimit
impl ContainerType for VelocityLimit
Sourceasync fn resolve_field(&self, ctx: &Context<'_>) -> ServerResult<Option<Value>>
async fn resolve_field(&self, ctx: &Context<'_>) -> ServerResult<Option<Value>>
Resolves a field value and outputs it as a json value
async_graphql::Value. Read moreSourcefn collect_all_fields<'a>(
&'a self,
ctx: &ContextBase<'a, &'a Positioned<SelectionSet>>,
fields: &mut Fields<'a>,
) -> Result<(), ServerError>
fn collect_all_fields<'a>( &'a self, ctx: &ContextBase<'a, &'a Positioned<SelectionSet>>, fields: &mut Fields<'a>, ) -> Result<(), ServerError>
Collect all the fields of the container that are queried in the
selection set. Read more
Sourcefn find_entity(
&self,
_: &ContextBase<'_, &Positioned<Field>>,
_params: &ConstValue,
) -> impl Future<Output = Result<Option<ConstValue>, ServerError>> + Send
fn find_entity( &self, _: &ContextBase<'_, &Positioned<Field>>, _params: &ConstValue, ) -> impl Future<Output = Result<Option<ConstValue>, ServerError>> + Send
Find the GraphQL entity with the given name from the parameter. Read more
Sourceimpl From<VelocityLimit> for VelocityLimit
impl From<VelocityLimit> for VelocityLimit
Sourcefn from(velocity_limit: VelocityLimit) -> Self
fn from(velocity_limit: VelocityLimit) -> Self
Converts to this type from the input type.
Sourceimpl OutputType for VelocityLimit
impl OutputType for VelocityLimit
Sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
Sourceasync fn resolve(
&self,
ctx: &ContextSelectionSet<'_>,
_field: &Positioned<Field>,
) -> ServerResult<Value>
async fn resolve( &self, ctx: &ContextSelectionSet<'_>, _field: &Positioned<Field>, ) -> ServerResult<Value>
Resolve an output value to
async_graphql::Value.Sourcefn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
impl ObjectType for VelocityLimit